#!/bin/bash

VER=`grep VER src/mytube/lgc/conf.py | grep -o "[0-9.\-]\+"`
if [ -z $VER ]; then
	echo "cannot detect version"
	exit
fi
DIR=mytube-$VER
rm -fr ../$DIR
cd ..
svn export mytube $DIR
cd $DIR
dpkg-buildpackage -rfakeroot

